@@ -13,7 +13,7 @@ def get_aux(auxfile):
 
     if not os.path.exists(auxfile):
         # print(auxfile)
-        warn("Could not find bibtex file:", auxfile)
+        warn("Could not find bibtex file: " + auxfile + " testing for troubles")
 
         if os.path.dirname(auxfile):
             print("Directory for auxfile does not exist:", os.path.dirname(auxfile))
