@@ -71,8 +71,8 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
 
         if censor_files:
             lines = fix_f(lines, dbug)
-            if "pacman" in str(file):
-                print("sdaf")
+            # if "pacman" in str(file):
+            #     print("sdaf")
             lines, nB, cut = fix_b(lines)
         else:
             nB = 0
